Re-exports
pub use key::*;pub use key_backup::*;pub use session::*;pub use presence::*;
Modules
Structs
- DbAccess
Token - DbDevice
Inbox - DbPassword
- DbProfile
- DbRefresh
Token - DbUser
- DbUser
Data - DbUser
Device - DbUser
Filter - NewDb
Access Token - NewDb
Device Inbox - NewDb
Password - NewDb
Profile - NewDb
Refresh Token - NewDb
User - NewDb
User Data - NewDb
User Device - NewDb
User Filter
Functions
- add_
to_ device_ event - all_
device_ ids - avatar_
url - Get the avatar_url of a user.
- blurhash
- Get the blurhash of a user.
- clean_
signatures - Ensure that a user only sees signatures from themselves and the target user
- count
- Returns the number of users registered on this server.
- create_
device - create_
filter - data_
changes - Returns all changes to the account data that happened after
since. - deactivate
- delete_
dehydrated_ devices - display_
name - Returns the display_name of a user on this homeserver.
- get_
data - get_
device - get_
filter - get_
global_ data - get_
profile - get_
room_ data - Searches the account data for a specific kind.
- get_
to_ device_ events - get_
user - invited_
rooms - Returns an iterator over all rooms a user was invited to.
- is_
device_ exists - joined_
rooms - Returns an iterator over all rooms this user joined.
- knocked_
rooms - list_
local_ users - Returns a list of local users as list of usernames.
- remove_
all_ devices - remove_
device - remove_
to_ device_ events - set_
data - Places one event in the account data of the user and removes the previous entry.
- set_
display_ name - set_
token - user_
exists - Check if a user has an account on this homeserver.
- user_
is_ ignored - Returns true/false based on whether the recipient/receiving user has blocked the sender