pub fn set_data(
user_id: &UserId,
room_id: Option<OwnedRoomId>,
event_type: &str,
json_data: JsonValue,
) -> DataResult<DbUserData>Expand description
Places one event in the account data of the user and removes the previous entry.
pub fn set_data(
user_id: &UserId,
room_id: Option<OwnedRoomId>,
event_type: &str,
json_data: JsonValue,
) -> DataResult<DbUserData>Places one event in the account data of the user and removes the previous entry.