pub struct DbConfig {
pub url: String,
pub pool_size: u32,
pub min_idle: Option<u32>,
pub tcp_timeout: u64,
pub connection_timeout: u64,
pub statement_timeout: u64,
pub helper_threads: usize,
pub enforce_tls: bool,
}Fields
url: StringSettings for the primary database. This is usually writeable, but will be read-only in some configurations. An optional follower database. Always read-only.
pool_size: u32min_idle: Option<u32>tcp_timeout: u64Number of seconds to wait for unacknowledged TCP packets before treating the connection as broken. This value will determine how long crates.io stays unavailable in case of full packet loss between the application and the database: setting it too high will result in an unnecessarily long outage (before the unhealthy database logic kicks in), while setting it too low might result in healthy connections being dropped.
connection_timeout: u64Time to wait for a connection to become available from the connection pool before returning an error. Time to wait for a connection to become available from the connection pool before returning an error.
statement_timeout: u64Time to wait for a query response before canceling the query and returning an error.
helper_threads: usizeNumber of threads to use for asynchronous operations such as connection creation.
enforce_tls: boolWhether to enforce that all the database connections are encrypted with TLS.