Module user

Module user 

Re-exports

pub use key::*;
pub use key_backup::*;
pub use session::*;
pub use presence::*;

Modules

key
key_backup
presence
pusher
session

Structs

DbAccessToken
DbDeviceInbox
DbPassword
DbProfile
DbRefreshToken
DbUser
DbUserData
DbUserDevice
DbUserFilter
NewDbAccessToken
NewDbDeviceInbox
NewDbPassword
NewDbProfile
NewDbRefreshToken
NewDbUser
NewDbUserData
NewDbUserDevice
NewDbUserFilter

Functions

add_to_device_event
all_device_ids
avatar_url
Get the avatar_url of a user.
blurhash
Get the blurhash of a user.
clean_signatures
Ensure that a user only sees signatures from themselves and the target user
count
Returns the number of users registered on this server.
create_device
create_filter
data_changes
Returns all changes to the account data that happened after since.
deactivate
delete_dehydrated_devices
display_name
Returns the display_name of a user on this homeserver.
get_data
get_device
get_filter
get_global_data
get_profile
get_room_data
Searches the account data for a specific kind.
get_to_device_events
get_user
invited_rooms
Returns an iterator over all rooms a user was invited to.
is_device_exists
joined_rooms
Returns an iterator over all rooms this user joined.
knocked_rooms
list_local_users
Returns a list of local users as list of usernames.
remove_all_devices
remove_device
remove_to_device_events
set_data
Places one event in the account data of the user and removes the previous entry.
set_display_name
set_token
user_exists
Check if a user has an account on this homeserver.
user_is_ignored
Returns true/false based on whether the recipient/receiving user has blocked the sender